# Windows 96 msgroom bot library
Create a Windows 96 msgroom bot using this library!
# What is Windows 96 msgroom?
A website where you can talk with other people: [Click here](https://msgroom.windows96.net/).
# Installation
To install from PyPi, use this command:
```
<your python interpreter> -m pip install --upgrade w96msgroom
```
## Getting the latest developer version
To get the latest developer version, first clone this repository:
```
git clone https://github.com/GEOEGII555/w96msgroom.py w96msgroom
```
Then go to the newly cloned directory with `cd w96msgroom` and run:
```
<your python interpreter> -m pip install .
```
And it should be done.

# Documentation

The documentation is located on our [GitHub repository](https://github.com/GEOEGII555/w96msgroom.py). See the `documentation` folder.